Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(510)

Unified Diff: public/web/WebFormControlElement.h

Issue 194923003: Move common methods to WebFormControlElement interface (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Created 6 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/web/WebTextAreaElement.cpp ('k') | public/web/WebInputElement.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: public/web/WebFormControlElement.h
diff --git a/public/web/WebFormControlElement.h b/public/web/WebFormControlElement.h
index e771d3cb4a8c0d97d84c4c983f669b32e17b1a4b..a6883613b22c25438d3496d08f95dd53c07709e6 100644
--- a/public/web/WebFormControlElement.h
+++ b/public/web/WebFormControlElement.h
@@ -64,20 +64,43 @@ public:
BLINK_EXPORT bool isAutofilled() const;
BLINK_EXPORT void setAutofilled(bool);
- // This returns the non-sanitized, exact value inside the text input field
+ // Returns true if autocomplete attribute of the element is not set as "off".
+ BLINK_EXPORT bool autoComplete() const;
+
+ // Sets value for input element, textarea element and select element. For select
+ // element it finds the option with value matches the given parameter and make the
+ // option as the current selection.
+ BLINK_EXPORT void setValue(const WebString&, bool sendChangeEvent = false);
+ // Returns value of element. For select element, it returns the value of
+ // the selected option if present. If no selected option, an empty string
+ // is returned. For any other types of elements, a null string is returned.
+ BLINK_EXPORT WebString value() const;
+ // Sets suggested value for element. The goal of introducing suggested value
+ // is to not leak any information to JavaScript.
+ BLINK_EXPORT void setSuggestedValue(const WebString&);
+ // Returns suggested value for input element or textarea element. If neither
+ // input element nor textarea element, a null string is returned.
+ BLINK_EXPORT WebString suggestedValue() const;
+
+ // Returns the non-sanitized, exact value inside the text input field
// or insisde the textarea. If neither input element nor textarea element,
// a null string is returned.
BLINK_EXPORT WebString editingValue() const;
- // The returned value represents a cursor/caret position at the current
+ // Sets character selection range.
+ BLINK_EXPORT void setSelectionRange(int start, int end);
+ // Returned value represents a cursor/caret position at the current
// selection's start for text input field or textarea. If neither input
// element nor textarea element, 0 is returned.
BLINK_EXPORT int selectionStart() const;
- // The returned value represents a cursor/caret position at the current
+ // Returned value represents a cursor/caret position at the current
// selection's end for text input field or textarea. If neither input
// element nor textarea element, 0 is returned.
BLINK_EXPORT int selectionEnd() const;
+ // Returns direction of text of element.
+ BLINK_EXPORT WebString directionForFormData() const;
+
// Returns the name that should be used for the specified |element| when
// storing autofill data. This is either the field name or its id, an empty
// string if it has no name and no id.
« no previous file with comments | « Source/web/WebTextAreaElement.cpp ('k') | public/web/WebInputElement.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698